/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) HengShanCompany 2009-2019. All rights reserved.
 * Description: iommu driver
 * Author: HengShan
 * Version: Initial Draft
 * Create: 2009-12-16
 */

#ifndef _EXT_IOMMU_H_
#define _EXT_IOMMU_H_

#include <linux/list.h>
#include <linux/hengshan/iommu_ext.h>
#include <linux/platform_device.h>
#include <linux/dma-mapping.h>
#ifdef CONFIG_SOCT_IOMMU_API
/**
 * iommu domain interface
 */
size_t drv_iommu_iova_size(void);
size_t drv_iommu_iova_available(void);
void drv_iommu_free_iova(unsigned long iova, size_t size);
unsigned long drv_iommu_alloc_iova(size_t size, unsigned long align);

int drv_iommu_map_domain(struct scatterlist *sg, struct iommu_map_format *format);
int drv_iommu_unmap_domain(const struct iommu_map_format *format);

phys_addr_t drv_iommu_domain_iova_to_phys(unsigned long iova);

unsigned int drv_iommu_page_size(void);
bool drv_iommu_off_on(void);
int drv_iommu_get_info(unsigned long *iova_start, unsigned long *pgtbl_base);
void drv_get_iommu_ptable_addr(unsigned long *pt_addr, unsigned long *err_rdaddr, unsigned long *err_wraddr);
struct bus_type *drv_get_iommu_bus(void);
#else

/**
 * iommu domain interface
 */
static inline __maybe_unused int drv_iommu_map_domain(struct scatterlist *sg, struct iommu_map_format *format)
{
	return 0;
}

static inline int __maybe_unused drv_iommu_unmap_domain(const struct iommu_map_format *format)
{
	return 0;
}

static inline __maybe_unused phys_addr_t drv_iommu_domain_iova_to_phys(unsigned long iova)
{
	return 0;
}
static inline unsigned int __maybe_unused drv_iommu_page_size(void)
{
	return SZ_4K;
}

static bool __maybe_unused drv_iommu_off_on(void)
{
	return false;
}

static inline int __maybe_unused drv_iommu_get_info(unsigned long *iova_start, unsigned long *pgtbl_base)
{
	return 0;
}

static inline void __maybe_unused drv_get_iommu_ptable_addr(unsigned long *pt_addr, unsigned long *err_rdaddr,
	unsigned long *err_wraddr)
{
}

static inline struct bus_type __maybe_unused *drv_get_iommu_bus(void)
{
	return NULL;
}
#endif /* CONFIG_SOCT_IOMMU_API */

#endif /* _EXT_IOMMU_H_ */
