// SPDX-License-Identifier: GPL-2.0
/*
 * Copyright (c) HengShanCompany 2021-2021. All rights reserved.
 * Description: ion external kernel-mode interfaces
 * Author: HengShan
 * Create: 2021-05-24
 */

#ifndef __ION_EXT_H__
#define __ION_EXT_H__

#include "../drivers/staging/android/ion/ion.h"
#include <linux/dma-buf.h>

struct dma_buf *ion_alloc_dmabuf(size_t len, unsigned int heap_id_mask,
				 unsigned int flags, const char *name,
				 void *priv_data, size_t priv_len);
void ion_free_dmabuf(struct dma_buf *dmabuf);
int ion_close_fd(int fd);

 /* memtype is 0,  addr is cma mem; memtype is not 0, addr is nssmmu addr */
struct dma_buf *get_dmabuf_by_addr(phys_addr_t addr, int memtype,
				   phys_addr_t *base_addr);
int set_tee_mem_info(phys_addr_t mem_info, phys_addr_t sec_smmu,
		     struct dma_buf *dmabuf,
		     unsigned long long handle_id);
struct dma_buf *get_dmabuf_by_tee_mem(phys_addr_t mem_info);
struct dma_buf *ion_get_dmabuf(phys_addr_t addr, size_t size, unsigned int heap_id);
unsigned int get_heap_id_mask(struct dma_buf *dmabuf);
int get_sec_handle_id_by_fd(int fd, int *sec_flag, unsigned long long *handle_id);
int set_buffer_cached(struct dma_buf *dma_buf, unsigned long flags);
struct sg_table *get_pages_from_buffer(struct dma_buf *dma_buf, size_t *size);
void drv_nssmmu_get_page_table_addr(unsigned long *pt_addr, unsigned long *err_rd_addr,
				    unsigned long *err_wr_addr);

struct dma_buf *ion_alloc_dmabuf_with_priv(size_t len, unsigned int heap_id_mask,
    unsigned int flags, const char *name,
    const void *ssm_data, size_t ssm_len,
    size_t priv_len);
struct dma_buf *drv_get_ion_priv_data_by_dma_buf(const struct dma_buf *dmabuf);

#endif
