/*
 * Copyright (c) CompanyNameMagicTag Co., Ltd. 2019-2019. All rights reserved.
 * Description: con_log.h
 * Author: BSP
 * Create: 2020-9-9
 */

#ifndef _CON_LOG_H
#define _CON_LOG_H

#include <linux/types.h>

#define MNTN_LOG_TAG CON_LOG_TAG
#define DEFAULT_LOG_PATH_ROOT "/log"
#define CON_LOG_PATH_NAME "/con_log/"
/* log buf size */
#define MAX_BUF_SIZE 0xA00000            /* 10M */
#define MIN_BUF_SIZE 0x10000             /* 64K */
#define DEFAULT_BUF_SIZE 0x500000        /* 5M */
#define MAX_FIXED_BUF_SIZE 0x40000       /* 256K */
#define MAX_MALLOC_BUF_SIZE \
		(DEFAULT_BUF_SIZE - MAX_FIXED_BUF_SIZE)  /* 128K */
/* file size */
#define MAX_FILE_SIZE 0x3200000                 /* 50M */
#define MIN_FILE_SIZE 0xA00000                  /* 10M */
#define DEFAULT_FILE_SIZE 0x3200000             /* 50M */
/* time size */
#define MAX_TIME (7 * 24 * 3600 * 1000)        /* 7day */
#define MIN_TIME (10 * 60 * 1000)               /* 10min */
#define ONE_MIN (60 * 1000)                     /* 1min */
#define ONE_HOUR (60 * ONE_MIN)                 /* 1hour */
/* over this value, add to console list */
#define EACH_RECORDED_MAX_LEN 0x10000           /* 64K */
/* malloc buf size each time */
#define EACH_MALLOC_SIZE 0x10000                /* 64K */
/* the buf end len to avoid overflow */
#define END_LEN 0x200                           /* 512B */

#define RECORDED_CON_LOG_NAME "message_"
#define RECORDING_CON_LOG_NAME "current_"
/* cmd parse macro */
#define CMD_SINGEL_MAX_LEN 32
#define CMD_NAME_LEN 32
#define CMD_TOTAL_MAX_LEN 80
#define CMD_MAX_NUM 4
#define PROC_MAX_LEN 32
#define PROC_FILE_LIMIT 0644

#define NETLINK_PORTID 1234

#define PSTORE_DIR_NAME "pstore"
#define PSTORE_NAME_MAXLEN 128

struct store_info {
	struct list_head node;
	size_t size;
	char *addr;
};

struct con_log_cmd {
	char name[CMD_NAME_LEN];
	int (*handler)(unsigned int argc, char (*argv)[CMD_SINGEL_MAX_LEN]);
};

struct pstore_head_info {
	struct list_head node;
	char name[PSTORE_NAME_MAXLEN];
	size_t size;
	char addr[0];
};
void con_log_write_cache(const char *buf, unsigned int len);
void con_log_save_pstore_log(const char *dst_dir);
void con_log_add_pstore_list(const char *name, const int name_len, const void *addr, size_t size);


#endif
